#
# spec file for package sile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  tests
Name:           sile
Version:        0.15.7
Release:        1.1
Summary:        Simon’s Improved Layout Engine
License:        MIT
URL:            https://sile-typesetter.org/
Source0:        sile-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        sile-rpmlintrc

# Lua modules
BuildRequires:  luajit
BuildRequires:  lua51-bit32
BuildRequires:  lua51-luarocks
BuildRequires:  luajit-devel
Requires:       lua51-bit32
BuildRequires:  lua51-cassowary
Requires:       lua51-cassowary
Requires:       lua51-cldr
BuildRequires:  lua51-cliargs
Requires:       lua51-cliargs
BuildRequires:  lua51-compat-5.3
Requires:       lua51-compat-5.3
BuildRequires:  lua51-cosmo
Requires:       lua51-cosmo
BuildRequires:  lua51-luaexpat
Requires:       lua51-luaexpat
BuildRequires:  lua51-luafilesystem
Requires:       lua51-luafilesystem
BuildRequires:  lua51-fluent
Requires:       lua51-fluent
BuildRequires:  lua51-linenoise
Requires:       lua51-linenoise
BuildRequires:  lua51-loadkit
Requires:       lua51-loadkit
Requires:       lua51-lpeg
Requires:       lua51-luaepnf
BuildRequires:  lua51-luarepl
Requires:       lua51-luarepl
BuildRequires:  lua51-luautf8
Requires:       lua51-luautf8
Requires:       lua51-penlight
BuildRequires:  lua51-luasec
Requires:       lua51-luasec
Requires:       lua51-luasocket
BuildRequires:  lua51-vstruct
Requires:       lua51-vstruct
BuildRequires:  lua51-zlib
# Without this Requires, lua51-zlib isn't counted as a dependency
Requires:       lua51-zlib

# Other Dependencies
%if %{with tests}
BuildRequires:  poppler-tools
BuildRequires:  sil-gentium-fonts
%endif
BuildRequires:  automake
BuildRequires:  fontconfig-devel
Requires:       fontconfig
BuildRequires:  freetype2-devel
Requires:       freetype2
BuildRequires:  fdupes
BuildRequires:  gcc-objc
BuildRequires:  git-core
Requires:       git-core
BuildRequires:  glibc-devel
Requires:       glibc
# Harfbuzz's minimum version is now 6 https://github.com/sile-typesetter/sile/releases/tag/v0.14.8
BuildRequires:  harfbuzz-devel >= 6.0.0
BuildRequires:  jq
BuildRequires:  libicu-devel
Requires:       icu
BuildRequires:  libpng16-compat-devel
BuildRequires:  libtool
BuildRequires:  pkgconf-pkg-config
BuildRequires:  zlib-devel
# Default font for SILE
# Without this, you have to specify the font every time you write a new .sil
Recommends:     sil-gentium-fonts
# Default font for math package
Suggests:       libertinus-fonts
# Default font for tate enabled classes
Suggests:       noto-sans-cjk-fonts
# Default mono font
Suggests:       hack-fonts

# Rust build dependencies. We don't need cargo packaging.
# Sile has a flags we have to respect it
BuildRequires:  cargo
# For tar scm lol
BuildRequires:  zstd

%description
SILE is a typesetting system; its job is to produce beautiful printed documents.
Conceptually, SILE is similar to TeX—from which it borrows some concepts and even
syntax and algorithms—but the similarities end there. Rather than being a
derivative of the TeX family SILE is a new typesetting and layout engine written
from the ground up using modern technologies and borrowing some ideas from
graphical systems such as InDesign.

%package -n libtexpdf0
Summary:        A PDF library extracted from TeX's dvipdfmx
Group:          Productivity/Publishing
License:        GPL-2.0-or-later

%description -n libtexpdf0
A PDF library extracted from TeX's dvipdfmx. Used in software such as SILE.
This package contains the shared library for libtexpdf.

%package -n libtexpdf-devel
Summary:        Development files for libtexpdf
License:        GPL-2.0-or-later
Requires:       libtexpdf0 = %{version}

%description -n libtexpdf-devel
A PDF library extracted from TeX's dvipdfmx. Used in software such as SILE.
This package contains the development files for libtexpdf.

%package        bash-completion
Summary:        Bash Completion for %{name}
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
Requires:       sile
BuildArch:      noarch

%description    bash-completion
Bash command-line completion support for %{name}.

%package        fish-completion
Summary:        Fish Completion for %{name}
Supplements:    (%{name} and fish)
Requires:       fish
Requires:       sile
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Supplements:    (%{name} and zsh)
Requires:       sile
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -p1 -a1

%build
# The macros uses this but we have to respect what upstream config.toml
# uses for the RUSTFLAGS
unset LIBSSH2_SYS_USE_PKG_CONFIG
export RUSTFLAGS=" -Clink-arg=-Wl,-z,relro,-z,now -C debuginfo=2 -C incremental=false -C strip=none"
export CARGO_AUDITABLE=auditable
export CARGO_FEATURE_VENDORED=1
export LUA_INCLUDE="-I/usr/include/luajit-5_1-2.1"
export CFLAGS="%optflags $(pkg-config --cflags-only-I luajit)"
export CXXFLAGS="%optflags $(pkg-config --cflags-only-I luajit)"
%configure \
	--disable-static \
	--disable-embeded-resources \
	--with-system-lua-sources \
	--with-system-luarocks

%make_build all

%install
# The macros uses this but we have to respect what upstream config.toml
# uses for the RUSTFLAGS
unset LIBSSH2_SYS_USE_PKG_CONFIG
export RUSTFLAGS=" -Clink-arg=-Wl,-z,relro,-z,now -C debuginfo=2 -C incremental=false -C strip=none"
export CARGO_AUDITABLE=auditable
export CARGO_FEATURE_VENDORED=1
export LUA_INCLUDE="$(pkg-config --cflags-only-I luajit)"
export CFLAGS="%optflags $(pkg-config --cflags-only-I luajit)"
export CXXFLAGS="%optflags $(pkg-config --cflags-only-I luajit)"
%make_install
rm %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}

%if %{with tests}
%check
make check
%endif

%ldconfig_scriptlets -n libtexpdf0
%ldconfig_scriptlets -n libtexpdf-devel

%files
%license LICENSE.md
%doc %{_datadir}/doc/sile/*
%dir %{_datadir}/doc/sile
%dir %{_datadir}/licenses/sile
%{_bindir}/sile
%{_bindir}/sile-lua
%{_datadir}/sile
%{_libdir}/sile
%{_mandir}/man1/sile.1%{?ext_man}
%{_mandir}/man1/sile-lua.1%{?ext_man}

%files -n libtexpdf0
%license %{_datadir}/licenses/libtexpdf/LICENSE
%dir %{_datadir}/licenses/libtexpdf
%{_libdir}/libtexpdf.so.0*

%files -n libtexpdf-devel
%{_includedir}/libtexpdf
%{_libdir}/libtexpdf.so

%files bash-completion
%license LICENSE.md
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%license LICENSE.md
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%license LICENSE.md
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Sun Dec  8 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.15.7
  * https://github.com/sile-typesetter/sile/releases/tag/v0.15.7
- Added luarocks as a BuildRequires
* Thu Nov 14 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.15.6
  * https://github.com/sile-typesetter/sile/releases/tag/v0.15.6
* Wed Sep 18 2024 Gordon Leung <pirateclip@protonmail.com>
- Update vendored deps to resolve boo#1230690
* Sat Aug 31 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.15.5:
  * New Features
  - packages: Support biblatex date field and improve date formatting
  * Bug Fixes
  - build: Fix distribution of unit tests clean up dist file list
  - classes: Make document state available during class's post init
  - cli: Suppress trace info in quiet for warnings but do show errors
  - packages: Parse and split all bibtex name fields
  - packages: Use non-breakable space in bibTeX name splitting, not tilde
* Fri Jun 28 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.15.4:
  * New Features
  - build: Add a developer target to test build dist without automake
  - languages: Add Brazilian Portuguese specific hyphenation point
  - packages: Biblatex data inheritance and field mapping
  - packages: Support `@string` syntax in bibTeX bibliography
  - packages: Support `@xdata` entry type and xdata field in bibTeX bibliography
  - packages: Support crossref field in bibTeX bibliography
  - tooling: Add developer target to build Rust API docs
  * Bug Fixes
  - build: Avoid building sile binaries if not using them
  * build: Avoid the perceived need for an extra automake cycle in dist tarball
  * build: Do not distribute main man page, requires Rust tooling
  * build: Don't distribute distfiles list with configure option specific output
  * languages: Always set Fluent locale when setting `document.language`
  * packages: Correct handling of ampersands and tildes in bibtex
  * packages: Ignore `@preamble`  in bibTeX bibliography
* Tue Jun 18 2024 Gordon Leung <pirateclip@protonmail.com>
- Add export LUA_INCLUDE="-I/usr/include/luajit-5_1-2.1"
  so that we are finally building with LuaJIT headers.
  * I don't know why the configure file does not detect them by default
    are they placed in a non-standard location?
  * Since the headers exist I will close boo#1226307 I guess...
* Tue Jun 18 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Point to use LuaJIT headers and use LuaJIT for Sile
* Fri Jun 14 2024 Gordon Leung <pirateclip@protonmail.com>
- Add zsh completion subpackage
- Fixup rpmlintrc
- Document that we are using lua51 includes because luajit includes
  are missing from the openSUSE package
  * boo#1226307
- Switch back to gcc because clang fails on armv7l
* Fri Jun 14 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update to 0.15.3:
  * A lot of breaking changes in the transition to 0.15.0
    https://github.com/sile-typesetter/sile/releases/tag/v0.15.0
  * Bug Fixes
  - build: Distribute vendored compat-5.3.c source file
  - build: Remove Git from configure dependencies
  - classes: Correct order of operations when paragraphs are ended manually
  - packages: Change retrograde package so 'target' version works as expected
  - build: Bundle all assets in source distribution
  - core: Allow LUA_PATH env var to take effect at runtime
- New build dependencies
  * cargo/rust
  * clang to replicate upstream's choice of c compiler
  * jq
- Switch to lua51 for luajit. luajit only supports lua51 for now
- New subpackages: fish and bash completions
* Thu May 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Change package to use obs_scm source service. Upstream now longer
  publishes xz tarballs.
- Add libtool BuildRquires and call autoreconf in prep: git source
  trees are not bootstrapped.
* Wed Feb  7 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.17
  * Features
  - languages: Enable explicit hyphen repetition handling in Croatian,
    Czech, Portuguese, Slovak and Spanish
  - packages: Add balancing option to makecolums command
* Sat Jan 27 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.16
  * Features
  - languages: Accomodate alternate Turkish hyphenation guidelines at apostrophes
  - typesetters: Support for speaker change introduced by em-dash
  * Bug Fixes
  - languages: Break at ela geminada in Catalan cancels the punt vola
  - languages: Break at explicit hyphen in Polish repeats the hyphen
  - languages: Remove multiple repetitions of U+00A0 nbsp in French
  - languages: U+00A0 nbsp in French causes unexpected word breaks
* Sun Dec 24 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.14
  * Features
  - cli: Change module load error to suggestion for how to install 3rd party modules
  - languages: U+00A0 non-breaking space must be stretchable by default
  - typesetters: Support U+00AD soft hyphen as discretionary break
  * Bug Fixes
  - cli: Stop outputting error messages twice on failure to process main file
  - core: Use nil-safe and Lua-version-robust table utils
  - packages: Adjust dropcap logic for letters with a depth
* Tue Oct 31 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.13
  * Features
  - classes: Add landscape option to base class
  - cli: Allow multiple runtime SILE_PATH segments
  * Bug Fixes
  - frames: Update frame constraints with new frame IDs after \makecolumns
* Wed Oct 11 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.12
  * Features
  - i18n: Add Portuguese localizations for bibtex package
  - utilities: Add utility function for console messages without trace info
  * Bug Fixes
  - build: Make sure vendored luarocks isn't a phony target that runs repeatedly
  - core: Allocate exactly what we use, not a guess with an extra just in case
  - core: Correct usage of HarfBuzz when passing a filtered list of shapers
  - core: Fixup class loader so cache is all Lua module specs
  - packages: Don't warn on TOC content change if not actually used
* Wed Aug 23 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.11
  * Bug Fixes:
  - core: Leave legacy masterFilename alone but use first input filename internally
  - core: Make masterFilename actually a filename
  - packages: Avoid mix-and-matching indents in fixed-width specimin blocks
  - utilities: Use real semver parser for deprecation warnings
* Tue Jul 11 2023 Gordon Leung <pirateclip@protonmail.com>
- Update to 0.14.10
  * Features
  - cli: Allow more than one input document
  - i18n: Add localized strings for Cantonese and Chinese
  - packages: Add document class styling in autodoc
  - packages: Provide API for registering raw handlers linked to packages
  * Bug Fixes:
  - build: Avoid build artifacts being listed for installation
  - core: Avoid stack overflow in Harfbuzz module
  - outputters: Setup --makedeps to play along without explicit --output
  - packages: Converters package no longer worked after 0.13.0
  - packages: Correct chord line height and chord font use
* Wed Apr 12 2023 Gordon Leung <pirateclip@protonmail.com>
  update: 0.14.8 -> 0.14.9
- Features
  * classes: Add Picas unit to cover all units speced in Docbook
  * classes: Implement the\code command in the plain class
  * cli: Add -q / --quiet flag to reduce output to essential errors
  * core: Support initializing fill glues with a width
  * packages: Introduce urlstyle hook in the url package
  * packages: New scalebox package for arbitrary box re-scaling
  * packages: Support migrating content in re-wrapped hboxes
  * typesetters: Implement hbox building logic in the typesetter
- Bug Fixes
  * build: Distribute SVG and FTL source files in packages
  * classes: Avoid justification issues with relative parindent
  * classes: Make sure un-numbered chapters make it in the ToC
  * classes: Parse bare number and percentage units in docbook images
  * classes: Setting current.hangIndent is a measurement
  * cli: Return success if --help explicitly requested
  * core,typesetter: Discretionary nodes are incorrectly handled
  * core: Ensure restoring settings top-level state does not error
  * outputters: Update Cairo/Podofo hbox debug API to match libtexpdf
  * packages: Correct image aspect preservation logic
  * packages: Fix output of debug breaks in infonode package
  * packages: Make sure pullquotes start in block mode
  * packages: Strip content position in ToC entries
  * etc. https://github.com/sile-typesetter/sile/releases/tag/v0.14.9
* Sat Jan 28 2023 Gordon Leung <pirateclip@protonmail.com>
  update: 0.14.7 -> 0.14.8
- Features
  * build: Pass build time configuration into Lua environment
  * core: Add variations support to font command
  * shapers: Instanciate variable fonts
  * shapers: Support named instances with FontConfig
  * shapers: Support named instances with macfonts
- Bug Fixes
  * build: Package license file for vendored lunamark fork
  * classes: Coerce option values to booleans
  * packages: Absolutize parskip heights on use
  * packages: Pass style & weight values to the math font loader
  * packages: Quote option values in documentation when necessary
  * tooling: Use luaEnv properly
* Fri Jan  6 2023 Gordon Leung <pirateclip@protonmail.com>
  update: 0.14.6 -> 0.14.7
- Features
  * build: Allow easy skip of font checks with FCMATCH=true
- Bug Fixes
  * build: Only check tooling to bulid manual if really needed
  * inputters: Rework SIL input to handle both junk outside of document tag and fragments
  * outputters: Patch up error message when failing to load font
  * shaper: Correct font-variants using opsz axis
  * shaper: Respect variations when shaping
  * tooling: Keep all Lua packages in same env for Nix
  * utilities: Tweak breadcrumbs to work under LuaJIT limitations
* Thu Dec 15 2022 pirateclip@protonmail.com
- Update to version 0.14.6:
  * chore(release): 0.14.6
  * fix(tooling): Exempt LuaJIT from external bit32 library requirement (#1654)
  * fix(shapers): Apply tracking settings even in font-fallback shaper
  * refactor(shapers): Move fallback shaper to dedicated module
  * fix(packages): Use casting to restore shaper state after fallbacks
  * docs(manual): Fix grid docs by actually loading the module for use
  * chore(tooling): Update commitlint rules for current module types
  * test(typesetters): Update expectations for bugs squashed during refactor
  * refactor(typesetters): Move tate typesetter functions to class
  * fix(packages): Fix \cite{key} in bibtex package (#1655)
  * fix(debug): Correct filename in debug info after includes (#1652)
* Sat Nov 19 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 0.14.4 -> 0.14.5
- Bug Fixes
  * inputters: Correct false positive detection of STDIN as Lua content
  * inputters: Don't duplicate passthrough content in AST
  * inputters: Permit content outside of the document note, e.g. comments or blanks
  * inputters: Relax SIL format sniffing to allow valid syntax
  * languages: Tidy up variable scope in languages/unicode.lua
  * measurements: Allow redefinition of existing units
  * packages: Ensure a page switch does not break boustrophedon
* Sat Nov  5 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 0.14.3 -> 0.14.4
- Features
  * packages: Add boolean noleadingzeros option to counter formatter
  * packages: Add new command \set-multilevel-counter
- Bug Fixes
  * classes: Always break out of hmode before processing \chapter headings
  * core: A typo in a variable prevents using -u with a class
  * languages: Make 'und' an exception to language name canonicalization
  * math: Fix insertion order of MathML children
  * packages: Account for depth when calculating rotation center
  * packages: Avoid forcing mirrored masters in twoside package
  * packages: Combine \unichar'ed chars with same font only
  * packages: Correct rotation origin calculation back to pre v0.10.0
  * packages: Don't inhibit page breaking after switching masters mid-page
  * packages: Make sure PDF initialized before rotate package directly calls it
  * packages: Rework simple and multilevel counters
  * packages: Textcase package name typo preventing using methods from code
- Reverts
  * Revert "docs(packages): Fixup unichar documentation, work around known bug (#1549)"
* Fri Sep  2 2022 Gordon Leung <pirateclip@protonmail.com>
  update: 0.14.2 -> 0.14.3
- Features
  * languages: Handle hyphenation of inter-word apostrophes in Turkish
  * packages: Add \open-spread function with more features that \open-double-page
  * packages: Add ability to select a page in PDF images
  * packages: Allow for customized content on otherwise blank filler pages
  * packages: Provide base directory to packages
  * utilities: Return image resolution with libtexpdf backend
- Bug Fixes
  * cli: Actually apply cli provided class options
  * cli: Allow CLI option to override document specified class
  * languages: Make Turkish hyphenation less bad around intraword apostrophes
  * nodes: Correct calculating width of postbreak discretionaries
  * nodes: Work around discressionaries being output when not wanted
  * packages: Fix over-aggressive eject in \open-double-page
  * packages: Homogenize image width and height as measurements
  - closes gh#sile-typesetter/sile#1504
  * packages: Make sure PDF initialized before PDF package does anything
  - closes gh#sile-typesetter/sile#1534
  * packages: Resolve src= relative to document for SVG images
  - closes gh#sile-typesetter/sile#1532
- Reverts
  * Revert "chore(cli): Output header before doing anything that might throw warnings"
  remove(pdf-metadata.patch): upstreamed
* Fri Aug 26 2022 Gordon Leung <pirateclip@protonmail.com>
  patch(pdf-metadata.patch): no return 0 at end of function
* Thu Aug 25 2022 Gordon Leung <pirateclip@protonmail.com>
- initial commit
